==> openshift-client-4.11.0-sources.jar: io/fabric8/openshift/client/dsl/internal/KubeAPIServerOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.DoneableKubeAPIServer;
import io.fabric8.openshift.api.model.operator.v1.KubeAPIServer;
import io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList;
import io.fabric8.openshift.api.model.operator.v1.DoneableKubeAPIServer;

import java.util.Map;
import java.util.TreeMap;


public class KubeAPIServerOperationsImpl extends OpenShiftOperation<KubeAPIServer, KubeAPIServerList, DoneableKubeAPIServer, Resource<KubeAPIServer, DoneableKubeAPIServer>> {

  public KubeAPIServerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public KubeAPIServerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("kubeapiservers"));
    this.type = KubeAPIServer.class;
    this.listType = KubeAPIServerList.class;
    this.doneableType = DoneableKubeAPIServer.class;
  }

  public KubeAPIServerOperationsImpl newInstance(OperationContext context) {
    return new KubeAPIServerOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.1.0-sources.jar: io/fabric8/openshift/client/dsl/internal/KubeAPIServerOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1.KubeAPIServer;
import io.fabric8.openshift.api.model.operator.v1.KubeAPIServerBuilder;
import io.fabric8.openshift.api.model.operator.v1.KubeAPIServerList;

import java.util.Map;
import java.util.TreeMap;


public class KubeAPIServerOperationsImpl extends OpenShiftOperation<KubeAPIServer, KubeAPIServerList, Resource<KubeAPIServer>> {

  public KubeAPIServerOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public KubeAPIServerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("kubeapiservers"));
    this.type = KubeAPIServer.class;
    this.listType = KubeAPIServerList.class;
  }

  public KubeAPIServerOperationsImpl newInstance(OperationContext context) {
    return new KubeAPIServerOperationsImpl(context);
  }

  @Override
  public KubeAPIServer edit(Visitor... visitors) {
    return patch(new KubeAPIServerBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
